@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -32,7 +37,7 @@ from manager.globals.constants import Constants
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2012 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
@@ -63,7 +68,7 @@ class ConstantsTestCase(unittest.TestCase):
 								"verbosityLabels",
 								"loggingDefaultFormatter",
 								"loggingSeparators",
-								"encodingFormat",
+								"encodingCodec",
 								"encodingError",
 								"applicationDirectory",
 								"providerDirectory",
@@ -130,32 +135,32 @@ class ConstantsTestCase(unittest.TestCase):
 
 		self.assertIsInstance(Constants.verbosityLabels, tuple)
 		for label in Constants.verbosityLabels:
-			self.assertIsInstance(label, str)
+			self.assertIsInstance(label, unicode)
 
 	def testLoggingDefaultFormaterAttribute(self):
 		"""
 		This method tests :attr:`manager.globals.constants.Constants.loggingDefaultFormatter` attribute.
 		"""
 
-		self.assertIsInstance(Constants.loggingDefaultFormatter, str)
+		self.assertIsInstance(Constants.loggingDefaultFormatter, unicode)
 
 	def testLoggingSeparatorsAttribute(self):
 		"""
 		This method tests :attr:`manager.globals.constants.Constants.loggingSeparators` attribute.
 		"""
 
-		self.assertIsInstance(Constants.loggingSeparators, str)
+		self.assertIsInstance(Constants.loggingSeparators, unicode)
 
-	def testEncodingFormatAttribute(self):
+	def testencodingCodecAttribute(self):
 		"""
-		This method tests :attr:`manager.globals.constants.Constants.encodingFormat` attribute.
+		This method tests :attr:`manager.globals.constants.Constants.encodingCodec` attribute.
 		"""
 
 		validEncodings = ("ascii",
 						"utf-8",
 						"cp1252")
 
-		self.assertIn(Constants.encodingFormat, validEncodings)
+		self.assertIn(Constants.encodingCodec, validEncodings)
 
 	def testEncodingErrorAttribute(self):
 		"""
